@@ -29,6 +29,7 @@ class LAS
 
     void filter_in_polygon(std::string wkt);
     void filter_local_maxima(NumericVector ws, double min_height, bool circular);
+    void filter_local_maxima(NumericVector ws);
     void filter_with_grid(S4 layout);
     void filter_shape(int method, NumericVector th, int k);
     void filter_progressive_morphology(NumericVector ws, NumericVector th);
@@ -37,11 +38,14 @@ class LAS
     void z_smooth(double size, int method, int shape, double sigma);
     void i_range_correction(DataFrame flightlines, double Rs, double f);
 
+    double range(NumericVector&, NumericVector& , NumericVector&, NumericVector&,  int, double);
+
     NumericVector rasterize(S4 layout, double subcircle, int method);
+    NumericVector compute_range(DataFrame flightlines);
 
     IntegerVector segment_snags(NumericVector neigh_radii, double low_int_thrsh, double uppr_int_thrsh, int pt_den_req, NumericMatrix BBPRthrsh_mat);
     IntegerVector segment_trees(double dt1, double dt2, double Zu, double R, double th_tree, double radius);
-    List knn_metrics(unsigned int k, DataFrame, DataFrame, SEXP call, SEXP env);
+    List point_metrics(unsigned int k, double r, DataFrame data, int nalloc, SEXP call, SEXP env);
 
   private:
     static bool coplanar (arma::vec& latent, arma::mat& coeff, NumericVector& th) { return latent[1] > th[0]*latent[2] && th[1]*latent[1] > latent[0]; }
