@@ -230,14 +230,22 @@ int fast_countunquantized(NumericVector x, double scale, double offset)
   int X = 0;
   int k = 0;
 
-  for (NumericVector::iterator it = x.begin(), end = x.end() ; it != end ; ++it)
+  // 32 bits fix
+  if (sizeof(void*) == 4)
   {
-    X = std::round((*it - offset)/scale);
-#ifdef _WIN32
-    if (std::abs(*it - (X * scale + offset)) > 1e-9) k++;
-#else
-    if (*it != X * scale + offset) k++;
-#endif
+    for (NumericVector::iterator it = x.begin(), end = x.end() ; it != end ; ++it)
+    {
+      X = std::round((*it - offset)/scale);
+      if (std::abs(*it - (X * scale + offset)) > 1e-9) k++;
+    }
+  }
+  else
+  {
+    for (NumericVector::iterator it = x.begin(), end = x.end() ; it != end ; ++it)
+    {
+      X = std::round((*it - offset)/scale);
+      if (*it != X * scale + offset) k++;
+    }
   }
 
   return k;
